# QStyler

![QStyler](https://raw.githubusercontent.com/alexpdev/QStyler/master/assets/QStylerLogo.png)

------------------------------

![GitHub repo size](https://img.shields.io/github/repo-size/alexpdev/qstyler?color=orange)
![GitHub License](https://img.shields.io/github/license/alexpdev/qstyler?color=red&logo=apache)
![PyPI - Downloads](https://img.shields.io/pypi/dm/qstyler?color=brown)
![GitHub Last Commit](https://badgen.net/github/last-commit/alexpdev/qstyler?color=blue&icon=github)
[![CI](https://github.com/alexpdev/QStyler/actions/workflows/windows.yml/badge.svg?branch=master&event=push)](https://github.com/alexpdev/QStyler/actions/workflows/windows.yml)
[![CI](https://github.com/alexpdev/QStyler/actions/workflows/mac.yml/badge.svg?branch=master&event=push)](https://github.com/alexpdev/QStyler/actions/workflows/mac.yml)
![GitHub repo size](https://img.shields.io/github/repo-size/alexpdev/qstyler)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/1e7fc4df9f66443daa887c740b05335d)](https://www.codacy.com/gh/alexpdev/QStyler/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=alexpdev/QStyler&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/alexpdev/QStyler/branch/main/graph/badge.svg?token=jpj9Rgriqi)](https://codecov.io/gh/alexpdev/QStyler)

## 🌐 Overview

GUI tool for testing Qt StyleSheets and their effect on widgets.

![QStyler.gif](https://raw.githubusercontent.com/alexpdev/QStyler/master/assets/styler.gif)

## Prerequisites

Before you begin, ensure you have met the following requirements:

- You have installed the latest version of `python3`
- You have installed `PySide6`.

## Installing QStyler

To install QStyler, follow these steps:

### **PyPI**

```bash
pip install QStyler
qstyler
```

### **Git**

```bash
git clone https://github.com/alexpdev/qstyler.git
cd qstyler
pip install .
qstyler
```

Alternatively there are pre-compiled executables in the releases section.

## Contributing to QStyler

To contribute to QStyler, follow these steps:

1. Fork this repository.
2. Create a branch: `git checkout -b <branch_name>`.
3. Make your changes and commit them: `git commit -m '<commit_message>'`
4. Push to the original branch: `git push origin <project_name>/<location>`
5. Create the pull request.

Alternatively see the GitHub documentation on [creating a pull request](https://help.github.com/en/github/collaborating-with-issues-and-pull-requests/creating-a-pull-request).

## License

This project uses the following license: Apache 2.0 Software License

![coverage](https://codecov.io/gh/alexpdev/QStyler/branch/main/graphs/sunburst.svg?token=jpj9Rgriqi)
